aboutsummaryrefslogtreecommitdiff
path: root/modules/FindDNSSD.cmake
diff options
context:
space:
mode:
authorAlexander Neundorf <neundorf@kde.org>2006-02-12 14:38:04 +0000
committerAlexander Neundorf <neundorf@kde.org>2006-02-12 14:38:04 +0000
commit75a07dd38b4a491a9d16d24492bea5c6ba90a8ff (patch)
tree0a65094e22bba335545b8ffe4a33fe7790edb21c /modules/FindDNSSD.cmake
parentbce40e0de3b22a291ecaa2b75358e6a998e1579b (diff)
downloadextra-cmake-modules-75a07dd38b4a491a9d16d24492bea5c6ba90a8ff.tar.gz
extra-cmake-modules-75a07dd38b4a491a9d16d24492bea5c6ba90a8ff.tar.bz2
-moved the cmake code to find kdewin32 out of FindKDE4.cmake and into its own FindKDEWIN32.cmake file
-added a new FindGNUWIN32.cmake file, which tries to find the gnuwin32 base directory -changed all "FOO_LIBRARY" variable names to "FOO_LIBRARIES" to be more consistent with the other cmake modules -added a macro_getenv_win_path() which replaces all backslahes with slashes from environment variables -modified the kde4_add_kcfg_files() command, so that the generated header is also processed by moc -all tests compile and link Alex CCMAIL:kde-buildsystem@kde.org The changes to the windows stuff are untested, since I don't have a windows box. Please check that everything still works. Please have a look at FindGNUWIN32.cmake, there are probably ways to improve this. The resulting GNUWIN32_DIR variable is used in other cmake modules as default path to search for headers and libraries. svn path=/trunk/KDE/kdelibs/; revision=508648
Diffstat (limited to 'modules/FindDNSSD.cmake')
-rw-r--r--modules/FindDNSSD.cmake11
1 files changed, 6 insertions, 5 deletions
diff --git a/modules/FindDNSSD.cmake b/modules/FindDNSSD.cmake
index 466dd3f2..7b6f81e3 100644
--- a/modules/FindDNSSD.cmake
+++ b/modules/FindDNSSD.cmake
@@ -3,7 +3,7 @@
#
# DNSSD_FOUND - system has DNSSD
# DNSSD_INCLUDE_DIR - the DNSSD include directory
# DNSSD_LIBRARY - Link these to use dnssd
# DNSSD_DEFINITIONS - Compiler switches required for using DNSSD
#
# need more test: look at into dnssd/configure.in.in
@@ -14,19 +14,19 @@ FIND_PATH(DNSSD_INCLUDE_DIR dns_sd.h
/usr/include/avahi-compat-libdns_sd/
)
-FIND_LIBRARY(DNSSD_LIBRARY NAMES dns_sd
+FIND_LIBRARY(DNSSD_LIBRARIES NAMES dns_sd
PATHS
/usr/lib
/usr/local/lib
)
-IF(DNSSD_INCLUDE_DIR AND DNSSD_LIBRARY)
+IF(DNSSD_INCLUDE_DIR AND DNSSD_LIBRARIES)
SET(DNSSD_FOUND TRUE)
-ENDIF(DNSSD_INCLUDE_DIR AND DNSSD_LIBRARY)
+ENDIF(DNSSD_INCLUDE_DIR AND DNSSD_LIBRARIES)
IF(DNSSD_FOUND)
IF(NOT DNSSD_FIND_QUIETLY)
- MESSAGE(STATUS "Found DNSSD: ${DNSSD_LIBRARY}")
+ MESSAGE(STATUS "Found DNSSD: ${DNSSD_LIBRARIES}")
ENDIF(NOT DNSSD_FIND_QUIETLY)
ELSE(DNSSD_FOUND)
IF(DNSSD_FIND_REQUIRED)
@@ -34,3 +34,4 @@ ELSE(DNSSD_FOUND)
ENDIF(DNSSD_FIND_REQUIRED)
ENDIF(DNSSD_FOUND)
+MARK_AS_ADVANCED(DNSSD_INCLUDE_DIR DNSSD_LIBRARIES)
@@ -3,7 +3,7 @@
# DNSSD_FOUND - system has DNSSD
# DNSSD_INCLUDE_DIR - the DNSSD include directory
-# DNSSD_LIBRARY - Link these to use dnssd
+# DNSSD_LIBRARIES - Link these to use dnssd
# DNSSD_DEFINITIONS - Compiler switches required for using DNSSD
#